==> haskell-primes-0.2.1.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primes
version: 0.2.1.0
id: primes-0.2.1.0-DucHvFsSuMZGOrOqeezksH
key: primes-0.2.1.0-DucHvFsSuMZGOrOqeezksH
license: BSD-3-Clause
maintainer: Sebastian Fischer
author: Sebastian Fischer
stability: experimental
homepage: http://github.com/sebfisch/primes
synopsis: Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.
category: Algorithms, Numerical
abi: 60aec7d7eb58e349f2fe04f3b0087fd0
exposed: True
exposed-modules:
    Data.Numbers.Primes
import-dirs: /usr/lib/ghc-8.4.3/site-local/primes-0.2.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/primes-0.2.1.0
hs-libraries: HSprimes-0.2.1.0-DucHvFsSuMZGOrOqeezksH
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html: /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primes-0.2.1.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primes
version: 0.2.1.0
id: primes-0.2.1.0-5h3YRSGjPOUEJVLnWwzVHR
key: primes-0.2.1.0-5h3YRSGjPOUEJVLnWwzVHR
license: BSD-3-Clause
maintainer: Sebastian Fischer
author: Sebastian Fischer
stability: experimental
homepage: http://github.com/sebfisch/primes
synopsis: Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.
category: Algorithms, Numerical
abi: 21c67b4a237cb2ad2296a44d11bb8785
exposed: True
exposed-modules:
    Data.Numbers.Primes
import-dirs: /usr/lib/ghc-8.6.1/site-local/primes-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/primes-0.2.1.0
hs-libraries: HSprimes-0.2.1.0-5h3YRSGjPOUEJVLnWwzVHR
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html: /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
